//
//'*****************************************************************************
//' Build 0135
//'
//' Project:  GDAL Lazarus Bindings
//' Purpose:  Types and Constants for OGR
//' Author:   Frank Warmerdam, warmerdam@pobox.com
//' Lazarus Wrapper : Prajuab Riabroy
//'*****************************************************************************
//' Copyright (c) 2005, Frank Warmerdam <warmerdam@pobox.com>
//'
//' Permission is hereby granted, free of charge, to any person obtaining a
//' copy of this software and associated documentation files (the "Software"),
//' to deal in the Software without restriction, including without limitation
//' the rights to use, copy, modify, merge, publish, distribute, sublicense,
//' and/or sell copies of the Software, and to permit persons to whom the
//' Software is furnished to do so, subject to the following conditions:
//'
//' The above copyright notice and this permission notice shall be included
//' in all copies or substantial portions of the Software.
//'
//' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//' OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//' FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//' LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//' FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//' DEALINGS IN THE SOFTWARE.
//'*****************************************************************************

unit ogr;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, gdal;

type
  TOGRSpatialReferenceH = POINTER;
  TOGRCoordinateTransformationH = POINTER;

  TOGREnvelope = record
    MinX : double;
    MaxX : double;
    MinY : double;
    MaxY : double;
  end;

  TOGRErr = (OGRERR_NONE = 0,
             OGRERR_NOT_ENOUGH_DATA = 1,    //* not enough data to deserialize */
             OGRERR_NOT_ENOUGH_MEMORY = 2,
             OGRERR_UNSUPPORTED_GEOMETRY_TYPE = 3,
             OGRERR_UNSUPPORTED_OPERATION = 4,
             OGRERR_CORRUPT_DATA = 5,
             OGRERR_FAILURE = 6,
             OGRERR_UNSUPPORTED_SRS = 7,
             OGRERR_INVALID_HANDLE = 8);

  POGRErr = ^ TOGRErr;

  TOGRwkbGeometryType = (wkbUnknown = 0,
                         wkbPoint = 1,
                         wkbLineString = 2,
                         wkbPolygon = 3,
                         wkbMultiPoint = 4,
                         wkbMultiLineString = 5,
                         wkbMultiPolygon = 6,
                         wkbGeometryCollection = 7,
                         wkbNone = 100,
                         wkbLinearRing = 101,
                         wkbPoint25D = $80000001,
                         wkbLineString25D = $80000002,
                         wkbPolygon25D = $80000003,
                         wkbMultiPoint25D = $80000004,
                         wkbMultiLineString25D = $80000005,
                         wkbMultiPolygon25D = $80000006,
                         wkbGeometryCollection25D = $80000007) ;
const
  wkb25DBit = $80000000;
  ogrZMarker = $21125711;
type
  TOGRwkbByteOrder = (wkbXDR = 0,     //* MSB/Sun/Motoroloa: Most Significant Byte First   */
                      wkbNDR = 1);    //* LSB/Intel/Vax: Least Significant Byte First      */
  TOGRFieldType = (OFTInteger = 0,
                   OFTIntegerList = 1,
                   OFTReal = 2,
                   OFTRealList = 3,
                   OFTString = 4,
                   OFTStringList = 5,
                   OFTWideString = 6,
                   OFTWideStringList = 7,
                   OFTBinary = 8,
                   OFTDate = 9,
                   OFTTime = 10,
                   OFTDateTime = 11,
                   OFTMaxType = 11);
  TOGRJustification = (OJUndefined = 0,
                       OJLeft = 1,
                       OJRight = 2);
const
  OGRNullFID = -1;
  OGRUnsetMarker = -21121;

  function OGRGeometryTypeToName(eType : TOGRwkbGeometryType) : PCHAR; stdcall; external External_lib name 'OGRGeometryTypeToName';
  function OGRMergeGeometryTypes(eMain, eExtra : TOGRwkbGeometryType) : TOGRwkbGeometryType; stdcall; external External_lib name 'OGRMergeGeometryTypes';

type
  POGRField = ^TOGRField;
  TOGRField = record
    case longint of
      0 : ( Integer : longint );
      1 : ( Real : double);
      2 : ( _String : Pchar );
      3 : ( IntegerList : record
            nCount : longint;
            paList : Plongint;
           end );
      4 : ( TRealList : record
              nCount : longint;
              paList : PDOUBLE;
           end );
      5 : ( TStringList : record
            nCount : longint;
            paList : PPCHAR;
           end );
      6 : ( TBinary : record
            nCount : longint;
            paData : PGByte;
          end );
      7 : ( TSet : record
            nMarker1 : longint;
            nMarker2 : longint;
           end );
      8 : ( TDate : record
            Year : TGInt16;
            Month : TGByte;
            Day : TGByte;
            Hour : TGByte;
            Minute : TGByte;
            Second : TGByte;
            TZFlag : TGByte;
          end );
  end;

  function OGRParseDate(pszInput : PCHAR; psOutput : POGRField;
                        nOptions : longint) : longint; stdcall; external External_lib name 'OGRParseDate';
  //* -------------------------------------------------------------------- */
  //*      Constants from ogrsf_frmts.h for capabilities.                  */
  //* -------------------------------------------------------------------- */
const
  OLCRandomRead         = 'RandomRead';
  OLCSequentialWrite    = 'SequentialWrite';
  OLCRandomWrite        = 'RandomWrite';
  OLCFastSpatialFilter  = 'FastSpatialFilter';
  OLCFastFeatureCount   = 'FastFeatureCount';
  OLCFastGetExtent      = 'FastGetExtent';
  OLCCreateField        = 'CreateField';
  OLCTransactions       = 'Transactions';
  OLCDeleteFeature      = 'DeleteFeature';
  OLCFastSetNextByIndex = 'FastSetNextByIndex';
  OLCStringsAsUTF8      = 'StringsAsUTF8';
  ODsCCreateLayer       = 'CreateLayer';
  ODsCDeleteLayer       = 'DeleteLayer';
  ODrCCreateDataSource  = 'CreateDataSource';
  ODrCDeleteDataSource  = 'DeleteDataSource';
type
  Togr_style_tool_class_id = (OGRSTCNone = 0,
                              OGRSTCPen = 1,
                              OGRSTCBrush = 2,
                              OGRSTCSymbol = 3,
                              OGRSTCLabel = 4,
                              OGRSTCVector = 5);

  Togr_style_tool_param_pen_id = (OGRSTPenColor = 0,
                                  OGRSTPenWidth = 1,
                                  OGRSTPenPattern = 2,
                                  OGRSTPenId = 3,
                                  OGRSTPenPerOffset = 4,
                                  OGRSTPenCap = 5,
                                  OGRSTPenJoin = 6,
                                  OGRSTPenPriority = 7,
                                  OGRSTPenLast = 8);

  Togr_style_tool_param_symbol_id = (OGRSTSymbolId = 0,
                                     OGRSTSymbolAngle = 1,
                                     OGRSTSymbolColor = 2,
                                     OGRSTSymbolSize = 3,
                                     OGRSTSymbolDx = 4,
                                     OGRSTSymbolDy = 5,
                                     OGRSTSymbolStep = 6,
                                     OGRSTSymbolPerp = 7,
                                     OGRSTSymbolOffset = 8,
                                     OGRSTSymbolPriority = 9,
                                     OGRSTSymbolFontName = 10,
                                     OGRSTSymbolOColor = 11,
                                     OGRSTSymbolLast = 12);

  Togr_style_tool_units_id = (OGRSTUGround = 0,
                              OGRSTUPixel = 1,
                              OGRSTUPoints = 2,
                              OGRSTUMM = 3,
                              OGRSTUCM = 4,
                              OGRSTUInches = 5);
  Togr_style_tool_param_brush_id = (OGRSTBrushFColor = 0,
                                    OGRSTBrushBColor = 1,
                                    OGRSTBrushId = 2,
                                    OGRSTBrushAngle = 3,
                                    OGRSTBrushSize = 4,
                                    OGRSTBrushDx = 5,
                                    OGRSTBrushDy = 6,
                                    OGRSTBrushPriority = 7,
                                    OGRSTBrushLast = 8);
  Togr_style_tool_param_label_id  = (OGRSTLabelFontName = 0,
                                     OGRSTLabelSize = 1,
                                     OGRSTLabelTextString = 2,
                                     OGRSTLabelAngle = 3,
                                     OGRSTLabelFColor = 4,
                                     OGRSTLabelBColor = 5,
                                     OGRSTLabelPlacement = 6,
                                     OGRSTLabelAnchor = 7,
                                     OGRSTLabelDx = 8,
                                     OGRSTLabelDy = 9,
                                     OGRSTLabelPerp = 10,
                                     OGRSTLabelBold = 11,
                                     OGRSTLabelItalic = 12,
                                     OGRSTLabelUnderline = 13,
                                     OGRSTLabelPriority = 14,
                                     OGRSTLabelStrikeout = 15,
                                     OGRSTLabelStretch = 16,
                                     OGRSTLabelAdjHor = 17,
                                     OGRSTLabelAdjVert = 18,
                                     OGRSTLabelHColor = 19,
                                     OGRSTLabelOColor = 20,
                                     OGRSTLabelLast = 21);


  TOGRSTUnitId = Togr_style_tool_units_id;
  TOGRSTPenParam = Togr_style_tool_param_pen_id;
  TOGRSTBrushParam = Togr_style_tool_param_brush_id;
  TOGRSTSymbolParam = Togr_style_tool_param_symbol_id;
  TOGRSTClassId = Togr_style_tool_class_id;
  TOGRSTLabelParam = Togr_style_tool_param_label_id;

  Pogr_style_tool_class_id  = ^Togr_style_tool_class_id;
  Pogr_style_tool_param_brush_id  = ^Togr_style_tool_param_brush_id;
  Pogr_style_tool_param_label_id  = ^Togr_style_tool_param_label_id;
  Pogr_style_tool_param_pen_id  = ^Togr_style_tool_param_pen_id;
  Pogr_style_tool_param_symbol_id  = ^Togr_style_tool_param_symbol_id;
  Pogr_style_tool_units_id  = ^Togr_style_tool_units_id;
  POGRSTBrushParam  = ^TOGRSTBrushParam;
  POGRSTClassId  = ^TOGRSTClassId;
  POGRSTLabelParam  = ^TOGRSTLabelParam;
  POGRSTPenParam  = ^TOGRSTPenParam;
  POGRSTSymbolParam  = ^TOGRSTSymbolParam;
  POGRSTUnitId  = ^TOGRSTUnitId;

  TOGRAxisOrientation = (OAO_Other = 0,
                         OAO_North = 1,
                         OAO_South = 2,
                         OAO_East = 3,
                         OAO_West = 4,
                         OAO_Up = 5,
                         OAO_Down = 6) ;

  function OSRAxisEnumToName(eOrientation : TOGRAxisOrientation) : PCHAR; stdcall; external External_lib name 'OSRAxisEnumToName';

  //* -------------------------------------------------------------------- */
  //*      Datum types (corresponds to CS_DatumType).                      */
  //* -------------------------------------------------------------------- */
type
  TOGRDatumType = (
      ODT_HD_Min = 1000,
      ODT_HD_Other = 1000,
      ODT_HD_Classic = 1001,
      ODT_HD_Geocentric = 1002,
      ODT_HD_Max = 1999,
      ODT_VD_Min = 2000,
      ODT_VD_Other = 2000,
      ODT_VD_Orthometric = 2001,
      ODT_VD_Ellipsoidal = 2002,
      ODT_VD_AltitudeBarometric = 2003,
      ODT_VD_Normal = 2004,
      ODT_VD_GeoidModelDerived = 2005,
      ODT_VD_Depth = 2006,
      ODT_VD_Max = 2999,
      ODT_LD_Min = 10000,
      ODT_LD_Max = 32767);


const
  //SRS_WKT_WGS84 : PCHAR = 'GEOGCS[\"WGS 84\",DATUM[\"WGS_1984\",SPHEROID[\"WGS 84\",6378137,298.257223563,AUTHORITY[\"EPSG\",\"7030\"]],TOWGS84[0,0,0,0,0,0,0],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"degree\",0.0174532925199433,AUTHORITY[\"EPSG\",\"9108\"]],AUTHORITY[\"EPSG\",\"4326\"]]';

  //* ==================================================================== */
  //*      Some "standard" strings.                                        */
  //* ==================================================================== */

  SRS_PT_ALBERS_CONIC_EQUAL_AREA = 'Albers_Conic_Equal_Area';
  SRS_PT_AZIMUTHAL_EQUIDISTANT = 'Azimuthal_Equidistant';
  SRS_PT_CASSINI_SOLDNER = 'Cassini_Soldner';
  SRS_PT_CYLINDRICAL_EQUAL_AREA = 'Cylindrical_Equal_Area';
  SRS_PT_BONNE = 'Bonne';
  SRS_PT_ECKERT_I = 'Eckert_I';
  SRS_PT_ECKERT_II = 'Eckert_II';
  SRS_PT_ECKERT_III = 'Eckert_III';
  SRS_PT_ECKERT_IV = 'Eckert_IV';
  SRS_PT_ECKERT_V = 'Eckert_V';
  SRS_PT_ECKERT_VI = 'Eckert_VI';
  SRS_PT_EQUIDISTANT_CONIC = 'Equidistant_Conic';
  SRS_PT_EQUIRECTANGULAR = 'Equirectangular';
  SRS_PT_GALL_STEREOGRAPHIC = 'Gall_Stereographic';
  SRS_PT_GAUSSSCHREIBERTMERCATOR = 'Gauss_Schreiber_Transverse_Mercator';
  SRS_PT_GEOSTATIONARY_SATELLITE = 'Geostationary_Satellite';
  SRS_PT_GOODE_HOMOLOSINE = 'Goode_Homolosine';
  SRS_PT_GNOMONIC = 'Gnomonic';
  SRS_PT_HOTINE_OBLIQUE_MERCATOR = 'Hotine_Oblique_Mercator';
  SRS_PT_HOTINE_OBLIQUE_MERCATOR_TWO_POINT_NATURAL_ORIGIN=
                'Hotine_Oblique_Mercator_Two_Point_Natural_Origin';
  SRS_PT_LABORDE_OBLIQUE_MERCATOR = 'Laborde_Oblique_Mercator';
  SRS_PT_LAMBERT_CONFORMAL_CONIC_1SP = 'Lambert_Conformal_Conic_1SP';
  SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP = 'Lambert_Conformal_Conic_2SP';
  SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP_BELGIUM =
                                  'Lambert_Conformal_Conic_2SP_Belgium';
  SRS_PT_LAMBERT_AZIMUTHAL_EQUAL_AREA =
                                  'Lambert_Azimuthal_Equal_Area';
  SRS_PT_MERCATOR_1SP = 'Mercator_1SP';
  SRS_PT_MERCATOR_2SP = 'Mercator_2SP';
  SRS_PT_MILLER_CYLINDRICAL = 'Miller_Cylindrical';
  SRS_PT_MOLLWEIDE = 'Mollweide';
  SRS_PT_NEW_ZEALAND_MAP_GRID = 'New_Zealand_Map_Grid';
  SRS_PT_OBLIQUE_STEREOGRAPHIC = 'Oblique_Stereographic';
  SRS_PT_ORTHOGRAPHIC = 'Orthographic';
  SRS_PT_POLAR_STEREOGRAPHIC = 'Polar_Stereographic';
  SRS_PT_POLYCONIC='Polyconic';
  SRS_PT_ROBINSON = 'Robinson';
  SRS_PT_SINUSOIDAL = 'Sinusoidal';
  SRS_PT_STEREOGRAPHIC = 'Stereographic';
  SRS_PT_SWISS_OBLIQUE_CYLINDRICAL = 'Swiss_Oblique_Cylindrical';
  SRS_PT_TRANSVERSE_MERCATOR = 'Transverse_Mercator';
  SRS_PT_TRANSVERSE_MERCATOR_SOUTH_ORIENTED
                                 = 'Transverse_Mercator_South_Orientated';

  //* special mapinfo variants on Transverse Mercator */
  SRS_PT_TRANSVERSE_MERCATOR_MI_21 =
                                  'Transverse_Mercator_MapInfo_21';
  SRS_PT_TRANSVERSE_MERCATOR_MI_22 =
                                  'Transverse_Mercator_MapInfo_22';
  SRS_PT_TRANSVERSE_MERCATOR_MI_23 =
                                  'Transverse_Mercator_MapInfo_23';
  SRS_PT_TRANSVERSE_MERCATOR_MI_24 =
                                  'Transverse_Mercator_MapInfo_24';
  SRS_PT_TRANSVERSE_MERCATOR_MI_25 =
                                  'Transverse_Mercator_MapInfo_25';

  SRS_PT_TUNISIA_MINING_GRID =
                                  'Tunisia_Mining_Grid';
  SRS_PT_TWO_POINT_EQUIDISTANT =
                                  'Two_Point_Equidistant';
  SRS_PT_VANDERGRINTEN =  'VanDerGrinten';
  SRS_PT_KROVAK =          'Krovak';
  SRS_PT_IMW_POLYCONIC =   'International_Map_of_the_World_Polyconic';
  SRS_PT_WAGNER_I  =       'Wagner_I';
  SRS_PT_WAGNER_II =       'Wagner_II';
  SRS_PT_WAGNER_III =      'Wagner_III';
  SRS_PT_WAGNER_IV =       'Wagner_IV';
  SRS_PT_WAGNER_V =        'Wagner_V';
  SRS_PT_WAGNER_VI =       'Wagner_VI';
  SRS_PT_WAGNER_VII =      'Wagner_VII';


  SRS_PP_CENTRAL_MERIDIAN =        'central_meridian';
  SRS_PP_SCALE_FACTOR     =        'scale_factor';
  SRS_PP_STANDARD_PARALLEL_1 =     'standard_parallel_1';
  SRS_PP_STANDARD_PARALLEL_2 =     'standard_parallel_2';
  SRS_PP_PSEUDO_STD_PARALLEL_1 =   'pseudo_standard_parallel_1';
  SRS_PP_LONGITUDE_OF_CENTER =     'longitude_of_center';
  SRS_PP_LATITUDE_OF_CENTER =      'latitude_of_center';
  SRS_PP_LONGITUDE_OF_ORIGIN =     'longitude_of_origin';
  SRS_PP_LATITUDE_OF_ORIGIN =      'latitude_of_origin';
  SRS_PP_FALSE_EASTING  =          'false_easting';
  SRS_PP_FALSE_NORTHING =          'false_northing';
  SRS_PP_AZIMUTH =                 'azimuth';
  SRS_PP_LONGITUDE_OF_POINT_1 =    'longitude_of_point_1';
  SRS_PP_LATITUDE_OF_POINT_1  =    'latitude_of_point_1';
  SRS_PP_LONGITUDE_OF_POINT_2 =    'longitude_of_point_2';
  SRS_PP_LATITUDE_OF_POINT_2  =    'latitude_of_point_2';
  SRS_PP_LONGITUDE_OF_POINT_3 =    'longitude_of_point_3';
  SRS_PP_LATITUDE_OF_POINT_3  =    'latitude_of_point_3';
  SRS_PP_RECTIFIED_GRID_ANGLE =    'rectified_grid_angle';
  SRS_PP_LANDSAT_NUMBER =          'landsat_number';
  SRS_PP_PATH_NUMBER =             'path_number';
  SRS_PP_PERSPECTIVE_POINT_HEIGHT = 'perspective_point_height';
  SRS_PP_SATELLITE_HEIGHT =        'satellite_height';
  SRS_PP_FIPSZONE =                'fipszone';
  SRS_PP_ZONE =                    'zone';
  SRS_PP_LATITUDE_OF_1ST_POINT =   'Latitude_Of_1st_Point';
  SRS_PP_LONGITUDE_OF_1ST_POINT =  'Longitude_Of_1st_Point';
  SRS_PP_LATITUDE_OF_2ND_POINT =   'Latitude_Of_2nd_Point';
  SRS_PP_LONGITUDE_OF_2ND_POINT =  'Longitude_Of_2nd_Point';

  SRS_UL_METER =           'Meter';
  SRS_UL_FOOT  =           'Foot (International)'; //* or just 'FOOT'? */
  SRS_UL_FOOT_CONV =                   '0.3048';
  SRS_UL_US_FOOT =         'Foot_US'; //* or 'US survey foot' from EPSG */
  SRS_UL_US_FOOT_CONV =                '0.3048006096012192';
  SRS_UL_NAUTICAL_MILE =   'Nautical Mile';
  SRS_UL_NAUTICAL_MILE_CONV =          '1852.0';
  SRS_UL_LINK =            'Link';          //* Based on US Foot */
  SRS_UL_LINK_CONV =                   '0.20116684023368047';
  SRS_UL_CHAIN =           'Chain';         //* based on US Foot */
  SRS_UL_CHAIN_CONV =                  '20.116684023368047';
  SRS_UL_ROD =             'Rod';           //* based on US Foot */
  SRS_UL_ROD_CONV =                    '5.02921005842012';

  SRS_UA_DEGREE =          'degree';
  SRS_UA_DEGREE_CONV =                 '0.0174532925199433';
  SRS_UA_RADIAN =          'radian';

  SRS_PM_GREENWICH =       'Greenwich';

  SRS_DN_NAD27 =           'North_American_Datum_1927';
  SRS_DN_NAD83 =           'North_American_Datum_1983';
  SRS_DN_WGS72 =           'WGS_1972';
  SRS_DN_WGS84 =           'WGS_1984';

  SRS_WGS84_SEMIMAJOR =    6378137.0;
  SRS_WGS84_INVFLATTENING = 298.257223563;

implementation

end.

